@@ -29,35 +29,48 @@ class CompositeVideoClip(VideoClip):
       attribute set, then the duration of the composite video clip
       is computed automatically
 
-    transparent
-      If False, the clips are overlaid on a surface
-      of the color `bg_color`. If True, the clips are overlaid on
-      a transparent surface, so that all pixels that are transparent
-      for all clips will be transparent in the composite clip. More
-      precisely, the mask of the composite clip is then the composite
-      of the masks of the different clips. Only use `transparent=True`
-      when you intend to use your composite clip as part of another
-      composite clip and you care about its transparency.
-      
+    bg_color
+      Color for the unmasked and unfilled regions. Set to None for these
+      regions to be transparent (will be slower).
+    
+    If all clips with a fps attribute have the same fps, it becomes the fps of
+    the result.
+
     """
 
-    def __init__(self, clips, size=None, bg_color=None, transparent=False,
+    def __init__(self, clips, size=None, bg_color=None, use_bgclip=False,
                  ismask=False):
-                     
+
         if size is None:
             size = clips[0].size
         
         if bg_color is None:
             bg_color = 0.0 if ismask else (0, 0, 0)
+
+        if use_bgclip and (clips[0].mask is None):
+            transparent = False
+        else:
+            transparent = (bg_color is None)
         
+        fps_list = list(set([c.fps for c in clips if hasattr(c,'fps')]))
+        if len(fps_list)==1:
+            self.fps= fps_list[0]
+
         VideoClip.__init__(self)
         
         self.size = size
         self.ismask = ismask
         self.clips = clips
-        self.transparent = transparent
         self.bg_color = bg_color
-        self.bg = ColorClip(size, col=self.bg_color).get_frame(0)
+
+        if use_bgclip:
+            self.bg = clips[0]
+            self.clips = clips[1:]
+        else:
+            self.clips = clips
+            self.bg = ColorClip(size, col=self.bg_color)
+
+        
         
         # compute duration
         ends = [c.end for c in self.clips]
@@ -70,19 +83,19 @@ class CompositeVideoClip(VideoClip):
         if len(audioclips) > 0:
             self.audio = CompositeAudioClip(audioclips)
 
-        # compute mask
+        # compute mask if necessary
         if transparent:
             maskclips = [c.mask.set_pos(c.pos) for c in self.clips
                          if c.mask is not None]
             if maskclips != []:
-                self.mask = CompositeVideoClip(maskclips,self.size,
-                                        transparent=False, ismask=True)
+                self.mask = CompositeVideoClip(maskclips,self.size, ismask=True,
+                                               bg_color=0)
 
         def make_frame(t):
             """ The clips playing at time `t` are blitted over one
                 another. """
 
-            f = self.bg
+            f = self.bg.get_frame(t)
             for c in self.playing_clips(t):
                     f = c.blit_on(f, t)
             return f
@@ -97,11 +110,28 @@ class CompositeVideoClip(VideoClip):
 
 
 def clips_array(array, rows_widths=None, cols_widths=None,
-                transparent = False, bg_color = None):
+                bg_color = None):
+
+    """
+
+    rows_widths
+      widths of the different rows in pixels. If None, is set automatically.
+
+    cols_widths
+      widths of the different colums in pixels. If None, is set automatically.
+
+    cols_widths
+    
+    bg_color
+       Fill color for the masked and unfilled regions. Set to None for these
+       regions to be transparent (will be slower).
+
+    """
     
     array = np.array(array)
     sizes_array = np.array([[c.size for c in line] for line in array])
     
+    # find row width and col_widths automatically if not provided
     if rows_widths is None:
         rows_widths = sizes_array[:,:,1].max(axis=1)
     if cols_widths is None:
@@ -117,14 +147,12 @@ def clips_array(array, rows_widths=None, cols_widths=None,
             if (w < cw) or (h < rw):
                 clip = (CompositeVideoClip([clip.set_pos('center')],
                                           size = (cw,rw),
-                                          transparent = transparent,
                                           bg_color = bg_color).
                                      set_duration(clip.duration))
                 
             array[i,j] = clip.set_pos((x,y))
                  
     return CompositeVideoClip(array.flatten(), size = (xx[-1],yy[-1]),
-                              transparent=transparent,
                               bg_color = bg_color)
     
     
