@@ -52,8 +52,8 @@ class VideoFileClip(VideoClip):
         
         # Make a reader
         pix_fmt= "rgba" if has_mask else "rgb24"
-        self.reader = FFMPEG_VideoReader(filename, pix_fmt=pix_fmt)
-        
+        reader = FFMPEG_VideoReader(filename, pix_fmt=pix_fmt)
+        self.reader = reader
         # Make some of the reader's attributes accessible from the clip
         self.duration = self.reader.duration
         self.end = self.reader.duration
@@ -63,15 +63,15 @@ class VideoFileClip(VideoClip):
 
         if has_mask:
 
-            self.make_frame = lambda t: self.reader.get_frame(t)[:,:,:3]
-            mask_mf =  lambda t: self.reader.get_frame(t)[:,:,3]/255.0
+            self.make_frame = lambda t: reader.get_frame(t)[:,:,:3]
+            mask_mf =  lambda t: reader.get_frame(t)[:,:,3]/255.0
             self.mask = (VideoClip(ismask = True, make_frame = mask_mf)
                        .set_duration(self.duration))
             self.mask.fps = self.fps
 
         else:
 
-            self.make_frame = lambda t: self.reader.get_frame(t)
+            self.make_frame = lambda t: reader.get_frame(t)
         
         # Make a reader for the audio, if any.
         if audio and self.reader.infos['audio_found']:
