@@ -4,6 +4,7 @@ import re
 import numpy as np
 from moviepy.video.VideoClip import VideoClip, TextClip
 from moviepy.tools import cvsecs
+from moviepy.decorators import convert_to_seconds
 
 
 class SubtitlesClip(VideoClip):
@@ -80,6 +81,24 @@ class SubtitlesClip(VideoClip):
         
         self.make_frame = make_frame
         self.mask = VideoClip(make_mask_frame, ismask=True)
+
+    def in_subclip(self, t_start= None, t_end= None):
+        """ Returns a sequence of [(t1,t2), txt] covering all the given subclip
+        from t_start to t_end. The first and last times will be cropped so as
+        to be exactly t_start and t_end if possible. """
+
+        def is_in_subclip(t1,t2):
+            try:
+                return (t_start<=t1<t_end) or (t_start< t2 <=t_end)
+            except:
+                return False
+        def try_cropping(t1,t2):
+            try:
+                return (max(t1, t_start), min(t2, t_end))
+            except:
+                return (t1, t2)
+        return [(try_cropping(t1,t2), txt) for ((t1,t2), txt) in self.subtitles
+                                               if is_in_subclip(t1,t2)]
     
 
 
@@ -107,7 +126,7 @@ class SubtitlesClip(VideoClip):
     def match_expr(self, expr):
 
         return SubtitlesClip([e for e in self.subtitles
-                              if re.find(expr, e) != []])
+                              if re.findall(expr, e[1]) != []])
     
 
     def write_srt(self, filename):
